@@ -371,6 +371,9 @@ OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'
 # 个人签署方不支持设置企业名称，请确认签署人类型后重试。
 OPERATIONDENIED_ERRNOSUPPORTINDIVIDUALHASORGANIZATIONNAME = 'OperationDenied.ErrNoSupportIndividualHasOrganizationName'
 
+# 文件已被删除，请联系客服处理。
+OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
+
 # 文件与资源不匹配，请检查文件名与资源id数量以及对应关系，并在修改后重试。
 OPERATIONDENIED_FILENOMATCHRESOURCE = 'OperationDenied.FileNoMatchResource'
 
