@@ -1115,7 +1115,7 @@ class MpsClient(AbstractClient):
     def DescribeTasks(self, request):
         """* 该接口用于查询任务列表；
         * 当列表数据比较多时，单次接口调用无法拉取整个列表，可通过 ScrollToken 参数，分批拉取；
-        * 只能查询到最近三天（72 小时）内的任务。
+        * 只能查询到最近七天（168小时）内的任务。
 
         :param request: Request instance for DescribeTasks.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribeTasksRequest`
@@ -1822,7 +1822,7 @@ class MpsClient(AbstractClient):
         """对直播流媒体发起处理任务，功能包括：
 
         * 智能内容审核（画面鉴黄、敏感信息检测、声音鉴黄）；
-        * 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
+        * 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词、语音实时翻译）。
 
         直播流处理事件通知实时写入用户指定的消息队列 CMQ 中，用户需要从消息队列 CMQ 中获取事件通知结果，同时处理过程中存在输出文件的，会写入用户指定的输出文件的目标存储中。
 
@@ -1853,16 +1853,16 @@ class MpsClient(AbstractClient):
 
 
     def ProcessMedia(self, request):
-        """对 COS 中的媒体文件发起处理任务，功能包括：
-        1. 视频转码（带水印）；
+        """对 URL视频链接 或 COS 中的媒体文件发起处理任务，功能包括：
+        1. 视频转码（普通转码、极速高清转码、音视频增强）；
         2. 视频转动图；
         3. 对视频按指定时间点截图；
         4. 对视频采样截图；
         5. 对视频截图雪碧图；
         6. 对视频转自适应码流；
         7. 智能内容审核（鉴黄、敏感信息检测）；
-        8. 智能内容分析（标签、分类、封面、按帧标签）；
-        9. 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
+        8. 智能内容分析（标签、分类、封面、按帧标签、拆条、集锦、片头片尾）；
+        9. 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词、语音翻译、物体识别）。
 
         :param request: Request instance for ProcessMedia.
         :type request: :class:`tencentcloud.mps.v20190612.models.ProcessMediaRequest`
