@@ -29,6 +29,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 不支持该参数值。
 INVALIDPARAMETERVALUE_NOTSUPPORTED = 'InvalidParameterValue.NotSupported'
 
+# 字段不支持此值。
+INVALIDPARAMETERVALUE_PARAMETERSNOTSUPPORTED = 'InvalidParameterValue.ParametersNotSupported'
+
 # 参数值过大。
 INVALIDPARAMETERVALUE_TOOLARGE = 'InvalidParameterValue.TooLarge'
 
@@ -50,6 +53,9 @@ RESOURCENOTFOUND_AUTOSCALINGGROUPID = 'ResourceNotFound.AutoScalingGroupId'
 # 集群不存在。
 RESOURCENOTFOUND_CLUSTERID = 'ResourceNotFound.ClusterId'
 
+# 无法找到镜像ID。
+RESOURCENOTFOUND_IMAGEID = 'ResourceNotFound.ImageId'
+
 # 无法找到ID对应的弹性伸缩启动配置。
 RESOURCENOTFOUND_LAUNCHCONFIGURATIONID = 'ResourceNotFound.LaunchConfigurationId'
 
@@ -64,3 +70,9 @@ UNSUPPORTEDOPERATION_CLUSTERSTATUSNOTSUPPORT = 'UnsupportedOperation.ClusterStat
 
 # 类型节点不支持当前操作。
 UNSUPPORTEDOPERATION_INVALIDNODEROLE = 'UnsupportedOperation.InvalidNodeRole'
+
+# 节点状态不支持此操作。
+UNSUPPORTEDOPERATION_NODESTATUSNOTSUPPORT = 'UnsupportedOperation.NodeStatusNotSupport'
+
+# vpc冲突，不支持当前操作。
+UNSUPPORTEDOPERATION_VPCIDCONFLICT = 'UnsupportedOperation.VpcIdConflict'
